<?php
namespace Financeiro\Logic\ControleBancario\TransferenciaentreContas;

use \Financeiro\Entities\Ittransfbanc;
use \Financeiro\Entities\Movbancario;
use \Financeiro\Entities\Transfbanc;
use Geral\Util\Ambiente;
use \Geral\Util\DateUtil;;
use Teknisa\Entities\Ittestar;


class TransferenciaentreContas {
	const MOVBANCARIO = 'MOVBANCARIO';
	const CREDITO = 'C';
	
	/**
	 * Insere transferência bancária
	 * 
	 * @param unknown $nrorg
	 * @param unknown $cdempresa
	 * @param unknown $dttranbanc
	 * @param unknown $vrtranbanc
	 * @param unknown $dshisttbanc
	 * @param unknown $cdreducont
	 * @param unknown $nrtranbanc
	 * @param unknown $nrmovbanc
	 * @param unknown $idmovi
	 * @throws Exception
	 */
	public static function insereTransfBanc($nrorg, $cdempresa, $dttranbanc, $vrtranbanc, $dshisttbanc, 
											$cdreducont, $nrtranbanc, $nrmovbanc, $idmovi)
	{
		try {
			$connection = \Setforms2\Shared\Registry::getEntityManager();
			$connection->beginTransaction();
			
			$movbancario = new Movbancario();
			$movbancario->setCdreducont($cdreducont);
			$movbancario->setNrmovbanc($nrmovbanc);
			$movbancario->setDtmovbanc(self::formataData($dttranbanc));
			$movbancario->setIdmovbanc($idmovi);
			$movbancario->setVrmovbanc($vrtranbanc);
			$movbancario->setNrorg($nrorg);
			$movbancario->setDshismbanc($dshisttbanc);
			$movbancario->setIdorigmbanc('T');
			$movbancario->setIdstconext('0');
			$movbancario->setIdstatusctbbanc('P');
			$movbancario->persist();
			\Setforms2\Shared\Registry::getEntityManager()->flush();			
			
			$ittransfbanc = new Ittransfbanc();
			$ittransfbanc->setNrorg($nrorg);
			$ittransfbanc->setCdempresa($cdempresa);
			$ittransfbanc->setVrmovitbanc($vrtranbanc);
			$ittransfbanc->setCdreducont($cdreducont);
			$ittransfbanc->setNrtranbanc($nrtranbanc);
			$ittransfbanc->setIdmovitbanc($idmovi);
			$ittransfbanc->setNrmovbanc($nrmovbanc);
			$ittransfbanc->persist();
			
			\Setforms2\Shared\Registry::getEntityManager()->flush();
			
			//Finaliza a transação
			$connection->flush();
			$connection->commit();
		}	
		catch(\Exception $e){
			throw $e;
		}	
	}
	
	
	/**
	 * Exclui a transferência
	 * 
	 * @param unknown $nrtranbanc
	 * @param unknown $cdempresa
	 * @throws Exception
	 */
	public static function excluiTransferencia($nrtranbanc, $cdempresa) {
		try{		
			//Inicia transação
			$connection = \Setforms2\Shared\Registry::getEntityManager();
			$connection->beginTransaction();

			//exclusão do item da transferência			
			$ittransfbanc = Ittransfbanc::findByNrtranbancAndCdempresa($nrtranbanc, $cdempresa);
			foreach ($ittransfbanc as $i) {
                /** @var $movbancario Movbancario*/
                $movbancario = Movbancario::findOneByNrorgAndCdreducontAndNrmovbanc(
                    Ambiente::getNrorg(), $i->getCdreducont(), $i->getNrmovbanc()
                );
				$i->delete();

                //exclusao da movimentacao bancaria
                $movbancario->delete();
			}
			\Setforms2\Shared\Registry::getEntityManager()->flush();
			
			//exclusão da transferência
			$transfbanc = Transfbanc::findOneByNrtranbancAndCdempresa($nrtranbanc, $cdempresa);
			$transfbanc->delete();
			\Setforms2\Shared\Registry::getEntityManager()->flush();
			
			//Finaliza a transação
			$connection->flush();
			$connection->commit();
		}catch(\Exception $e){
			$connection->rollback();
			throw $e;
		}			
	}	
	

	/**
	 * Retorna o número do cheque da conta de crédito correspondente da transferência
	 * 
	 * @param unknown $nrtranbanc
	 * @param unknown $cdempresa
	 * @throws Exception
	 * @return unknown
	 */
	public static function retornaNrCheque($nrtranbanc, $cdempresa) {
		try{
			$ittransfbanc = Ittransfbanc::findOneByIdmovitbancAndNrtranbancAndCdempresa(self::CREDITO, $nrtranbanc, $cdempresa);
            $nrcheque = $ittransfbanc->getNrcheque();
            return $nrcheque;
		
		}catch(\Exception $e){
			throw $e;
		}
	}
	
	/**
	 * Retorna a conta corrente de crédito correspondente da transferência
	 * 
	 * @param unknown $nrtranbanc
	 * @param unknown $cdempresa
	 * @throws Exception
	 * @return unknown
	 */
	public static function retornaCdReduContCred($nrtranbanc, $cdempresa) {
		try{
            /** @var $ittransfbanc \Financeiro\Entities\Ittransfbanc */
			$ittransfbanc = \Financeiro\Entities\Ittransfbanc::findOneByIdmovitbancAndNrtranbancAndCdempresa(self::CREDITO, $nrtranbanc, $cdempresa);
			$cdreducont = $ittransfbanc->getCdreducont();
			return $cdreducont;
	
		}catch(\Exception $e){
			throw $e;
		}
	}
	
	/**
	 * Formata data
	 * 
	 * @param unknown $data
	 * @return Ambigous <\Setforms2\Shared\ORM\DateTime, \Setforms2\Shared\ORM\DateTime>
	 */
	private function formataData($data){
		$data = DateUtil::getDatadeString($data);
		$data = DateUtil::truncateData($data);
		return $data;
	}
}