<?php
/**
 * Namespace Suprimentos\Logic\Util
 *
 * PHP version 5
 *
 * @category Php
 * @package  Suprimentos\Logic\Util
 * @author   joaocorte <joao.corte@tecfood.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */

namespace Suprimentos\Logic\Util;

/**
 * Class Lista
 *
 * @category Php
 * @package  Suprimentos\Logic\Util
 * @author   joaocorte <joao.corte@tecfood.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */

class ListaUtilLogic {

    const TODOS_A   = 'A';
    const TODOS_T   = 'T';
    const NENHUM    = 'N';
    const VAZIO     = '';

    /**
     * Retorna os valores do multisearch concatenados
     *
     * @param Array $array
     * @param String $codigo Código da tabela (ex: CDFILIAL)
     *
     * @return string
     */
    public static function geraListaGeral($array, $campo)
    {
        try {
            $campo = strtolower($campo);

            if (is_array($array)) {
                $concatenado = "_";
                foreach ($array as $a) {
                    $concatenado .= $a[$campo] . '_';
                }
                return $concatenado;
            } elseif ($array === 'A') {
                return 'T';
            } else {
                return 'N';
            }

        } catch (\Exception $e){
            tk_warning($e->getMessage());
            return null;
        }
    }

    /**
     * Retorna os campos do Multisearch
     * Caso 'A' - Retorna 'T' e ''
     * Caso 'N' - Retorna '' e ''
     * Caso Array - Retorna array concatenado e ''
     *
     * @param $campo
     * @param $parametro
     * @param $tparametro
     * @return array|null
     */
    public function getParametrosMultisearch($campo, $parametro, $tparametro)
    {
        try {
            $retorno = tk_get_field_value($campo);

            if ($retorno == self::TODOS_A){
                return array($parametro => self::VAZIO, $tparametro => self::TODOS_T);
            } elseif ($retorno == self::NENHUM) {
                return array($parametro => self::VAZIO, $tparametro => self::VAZIO);
            } else {
                $retorno = $this->geraListaGeral($retorno, $campo);
                return array($parametro => $retorno, $tparametro => self::VAZIO);
            }

        } catch (\Exception $e){
            tk_warning($e->getMessage());
            return null;
        }
    }
}